function R = reliability(H,N)
%R = reliability(X,N);
%R = reliability(H,N);
%R = reliability(X,ind);
%
%reliability is a measure of the degree to which a random variable is 
%predictable. 

if(length(H) ~= 1)
    H = entropy(makePDF(H,N));
end
if(length(N) > 1)
    N = length(N);
end
R = 1-(H./log2(N));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function x = flatten(x)
%y = flatten(x)
%
%flatten compresses all data to one dimension.

x = x(1:round(prod(size(x))));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [p ind] = makePDF(x,n)
%[p ind] = makePDF(x,n);
%[p ind] = makePDF(x,ind);
%
%makePDF takes data in x and makes a probability distribution with N bins.
%
%Variables
%   p           =   The probability distribution.
%   ind         =   The bin center corresponding to each distribution value.
%   x           =   Data to be binned.
%   n           =   The number of bins.

rng = minmax(x);
if(length(n) == 1)
    ind = linspace(rng(1),rng(2),N+1);
else
    ind = n;
end
p = histc(x,ind);
p = p./sum(p);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function H = entropy(p)

% ENTROPY computes the entropy of a distribution.
% --------------
% H  = entropy(p)
% --------------
% Description: computes the entropy of a distribution.
% Input:       {p} is the discrete distibution. For two-element
%                   distribution, it suffices to supply with only one of
%                   the elements.
% Output:      {H} is the entropy value (in bits).

%  Liran Carmel
% Classification: Basic functions
% Last revision date: 29-Dec-2006

% check number of argumesnts
error(nargchk(1,1,nargin));

% check input
if length(p) == 1
    p = [p 1-p];
end
if abs(sum(p) - 1) > 1e-10
    error('Probability function is not normalized');
end

% calculate entropy
warning off
H = -p.*log2(p);
warning on
H = nansum(H);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%